@@ -1,9 +1,10 @@
-#-*- python -*-
+from __future__ import absolute_import
+from __future__ import unicode_literals
 import logging
 
 from ming.utils import LazyProperty
 from ming.orm.ormsession import ThreadLocalORMSession
-from pylons import tmpl_context as c
+from tg import tmpl_context as c
 from timermiddleware import Timer
 
 # Pyforge-specific imports
@@ -16,20 +17,19 @@ from allura.lib.repository import RepositoryApp
 from allura.app import SitemapEntry
 
 # Local imports
-from . import model as HM
 from . import version
 from .controllers import BranchBrowser
 
 log = logging.getLogger(__name__)
 
+
 class ForgeHgApp(RepositoryApp):
     '''This is the Hg app for Allura'''
     __version__ = version.__version__
     tool_label='Mercurial'
     tool_description="""
-        Mercurial is a distributed source control management tool that efficiently
-        handles projects of any size and offers an easy and intuitive
-        interface.
+        Mercurial ("hg") is a distributed version control system.
+        It is fast, easy to learn, and scalable.
     """
     ordinal=3
     forkable=True
@@ -44,6 +44,7 @@ class ForgeHgApp(RepositoryApp):
 
     @LazyProperty
     def repo(self):
+        from . import model as HM
         return HM.Repository.query.get(app_config_id=self.config._id)
 
     @property
@@ -62,7 +63,8 @@ class ForgeHgApp(RepositoryApp):
     def install(self, project):
         '''Create repo object for this tool'''
         super(ForgeHgApp, self).install(project)
-        HM.Repository(
+        from . import model as HM
+        repo = HM.Repository(
             name=self.config.options.mount_point,
             tool='hg',
             status='initializing',
@@ -74,6 +76,8 @@ class ForgeHgApp(RepositoryApp):
         init_from_path = self.config.options.get('init_from_path')
         if cloned_from_project_id is not None:
             cloned_from = HM.Repository.query.get(_id=cloned_from_repo_id)
+            repo.default_branch_name = cloned_from.default_branch_name
+            repo.additional_viewable_extensions = cloned_from.additional_viewable_extensions
             allura.tasks.repo_tasks.clone.post(
                 cloned_from_path=cloned_from.full_fs_path,
                 cloned_from_name=cloned_from.app.config.script_name(),
@@ -97,5 +101,6 @@ def hg_timers():
 
 
 def forgehg_timers():
+    from . import model as HM
     return Timer('hg_tool.{method_name}', HM.hg.HgImplementation, '*')
 
